# ray-package

A simple Python package to convert text to uppercase and lowercase.

## Installation

You can install the package via pip and then import function to_uppercase,to_lowercase:

```bash
pip install ray-helper=0.2.0